import { Component, ElementRef, EventEmitter, Input, NgModule, Output, ViewEncapsulation } from '@angular/core';
import { CommonModule } from '@angular/common';
import { MatButtonModule, MatIconModule, MatMenuModule, MatToolbarModule } from '@angular/material';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';

var PenSpinnerComponent = (function () {
    /**
     * @param {?} elementRef
     */
    function PenSpinnerComponent(elementRef) {
        var _this = this;
        this.elementRef = elementRef;
        this._defaultSpinnerSrc = './assets/images/ajax-small-loader.gif';
        this._spinnerSrc = '';
        this.isShow = true;
        this.setSpinnerSize = function () {
            if (!_this.elementRef.nativeElement)
                return;
            _this.elementRef.nativeElement.style.width = _this.height || 'auto';
            _this.elementRef.nativeElement.style.width = _this.width || 'auto';
        };
    }
    Object.defineProperty(PenSpinnerComponent.prototype, "spinnerSrc", {
        /**
         * @return {?}
         */
        get: function () {
            return (this._spinnerSrc && this._spinnerSrc.trim() && this._spinnerSrc.length > 0) ? this._spinnerSrc.trim() : this._defaultSpinnerSrc;
        },
        /**
         * @param {?} spinnerUrl
         * @return {?}
         */
        set: function (spinnerUrl) {
            this._spinnerSrc = (spinnerUrl && spinnerUrl.trim() && spinnerUrl.length > 0) ? spinnerUrl.trim() : this._defaultSpinnerSrc;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    PenSpinnerComponent.prototype.ngOnInit = function () {
    };
    return PenSpinnerComponent;
}());
PenSpinnerComponent.decorators = [
    { type: Component, args: [{
                selector: 'pen-spinner',
                template: "<section class=\"penetrace-spinner\" *ngIf=\"(isShow)\" [ngClass]=\"{ backdrop: backdrop}\"> <div class=\"penetrace-spinner__img-group\"> <img class=\"penetrace-spinner__logo\" src=\"{{logoSrc}}\" /> <img class=\"penetrace-spinner__spinner-icon\" src=\"{{spinnerSrc}}\" /> </div> </section>",
                styles: [".penetrace-spinner { position: absolute; top: 0; z-index: 1060; width: 100%; height: 100%; min-height: 50px; text-align: center; } .penetrace-spinner.backdrop { background-color: rgba(0, 0, 0, 0.15); } .penetrace-spinner:before { content: ''; display: inline-block; height: 100%; vertical-align: middle } .penetrace-spinner__img-group { display: inline-block; vertical-align: middle; } .penetrace-spinner__logo { display: block; } .penetrace-spinner__spinner-icon { max-width: 40px; max-height: 40px; } .penetrace-spinner img { /* position: absolute; top: 50%; left: 50%; z-index: 1200; margin-top: -15px; margin-left: -15px; */ } .penetrace-spinner .loader-logo img { width: 140px; margin-left: -67px; margin-top: -110px; height: auto; }"]
            },] },
];
/**
 * @nocollapse
 */
PenSpinnerComponent.ctorParameters = function () { return [
    { type: ElementRef, },
]; };
PenSpinnerComponent.propDecorators = {
    'logoSrc': [{ type: Input },],
    'spinnerSrc': [{ type: Input, args: ['spinnerSrc',] },],
    'backdrop': [{ type: Input },],
    'isShow': [{ type: Input },],
    'width': [{ type: Input },],
    'height': [{ type: Input },],
};

var PenSpinnerModule = (function () {
    function PenSpinnerModule() {
    }
    return PenSpinnerModule;
}());
PenSpinnerModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                exports: [PenSpinnerComponent, CommonModule],
                declarations: [PenSpinnerComponent],
                providers: [],
            },] },
];
/**
 * @nocollapse
 */
PenSpinnerModule.ctorParameters = function () { return []; };

var PenNavbarComponent = (function () {
    function PenNavbarComponent() {
        this.color = 'primary';
        this.fullName = '';
        this.profileImage = '';
        this.siteLogo = '';
        this.languageList = [];
        this.profileSettingList = [];
        this.activityOwnerList = [];
        this.leftLinkList = [];
        this.rightLinkList = [];
        this.clickHomeIcon = new EventEmitter();
        this.clickToggleIcon = new EventEmitter();
        this.selectLanguage = new EventEmitter();
        this.selectProfileSetting = new EventEmitter();
        this.defaultOptions = {
            showHomeIcon: true,
            showToggleIcon: true,
            showLanguage: true,
            showProfileSettings: true
        };
        this.defaultActivityOwnerList = [];
    }
    /**
     * @return {?}
     */
    PenNavbarComponent.prototype.ngOnInit = function () {
        this.defaultOptions = Object.assign(this.defaultOptions, this.options);
        this.defaultActivityOwnerList = this.getActivityOwnerList(this.activityOwnerList);
        this.selectedLanguage = this.selectedLanguage || { title: 'English' };
    };
    /**
     * @param {?} changes
     * @return {?}
     */
    PenNavbarComponent.prototype.ngOnChanges = function (changes) {
        if (changes.activityOwnerList) {
            this.defaultActivityOwnerList = this.getActivityOwnerList(changes.activityOwnerList.currentValue);
        }
    };
    /**
     * @return {?}
     */
    PenNavbarComponent.prototype.ngDoCheck = function () {
        this.defaultOptions = Object.assign(this.defaultOptions, this.options);
    };
    /**
     * @return {?}
     */
    PenNavbarComponent.prototype.onHomeIconClicked = function () {
        this.clickHomeIcon.emit();
    };
    /**
     * @return {?}
     */
    PenNavbarComponent.prototype.onToggleIconClicked = function () {
        this.clickToggleIcon.emit();
    };
    /**
     * @param {?} lang
     * @return {?}
     */
    PenNavbarComponent.prototype.onLanguageSelected = function (lang) {
        this.selectLanguage.emit(lang);
        this.selectedLanguage = lang;
    };
    /**
     * @param {?} setting
     * @return {?}
     */
    PenNavbarComponent.prototype.onProfileSettingSelected = function (setting) {
        this.selectProfileSetting.emit(setting);
    };
    /**
     * @param {?} activityOwnerList
     * @return {?}
     */
    PenNavbarComponent.prototype.getActivityOwnerList = function (activityOwnerList) {
        var /** @type {?} */ results = [];
        for (var /** @type {?} */ i = 0, /** @type {?} */ len = activityOwnerList.length; i < len; i++) {
            var /** @type {?} */ activityOwner = activityOwnerList[i];
            setActivityOwnerObject(activityOwner);
        }
        return results;
        /**
         * @param {?} activityOwner
         * @return {?}
         */
        function setActivityOwnerObject(activityOwner) {
            results.push(activityOwner);
            if (!activityOwner.childLevel) {
                activityOwner.childLevel = 0;
            }
            if (!activityOwner.menus) {
                return;
            }
            if (activityOwner.menus && activityOwner.menus.length) {
                var /** @type {?} */ level = activityOwner.childLevel;
                level++;
                for (var /** @type {?} */ i = 0, /** @type {?} */ len = activityOwner.menus.length; i < len; i++) {
                    var /** @type {?} */ child = activityOwner.menus[i];
                    child.childLevel = level;
                    setActivityOwnerObject(child);
                }
            }
        }
    };
    return PenNavbarComponent;
}());
PenNavbarComponent.decorators = [
    { type: Component, args: [{
                selector: 'pen-navbar',
                template: "<mat-toolbar class=\"pen-navbar\" color=\"{{color}}\"> <button *ngIf=\"defaultOptions.showHomeIcon\" mat-icon-button (click)=\"onHomeIconClicked()\"> <mat-icon>home</mat-icon> </button> <button *ngIf=\"defaultOptions.showToggleIcon\" mat-icon-button (click)=\"onToggleIconClicked()\"> <mat-icon>reorder</mat-icon> </button> <a mat-button *ngFor=\"let btn of leftLinkList\" [hidden]=\"btn.title === 'Home'\" [href]=\"btn.url\" target=\"_blank\"> <span>{{btn.title}}</span> </a> <div> <button *ngIf=\"defaultActivityOwnerList.length\" mat-icon-button [matMenuTriggerFor]=\"activityOwner\"> <mat-icon>keyboard_arrow_down</mat-icon> </button> <mat-menu #activityOwner=\"matMenu\" class=\"activity-owner-list\"> <a mat-menu-item *ngFor=\"let ao of defaultActivityOwnerList\" [href]=\"ao.url\" [disabled]=\"!ao.active\" target=\"_blank\"> <span class=\"child-level-{{ao.childLevel}}\">{{ao.title}}</span> </a> </mat-menu> </div> <span class=\"fill-remaining-space\"></span> <a mat-button *ngFor=\"let btn of rightLinkList\" [href]=\"btn.url\" target=\"_blank\"> <span>{{btn.title}}</span> </a> <div> <button *ngIf=\"defaultOptions.showLanguage && languageList.length\" mat-button [matMenuTriggerFor]=\"language\"> <span>{{selectedLanguage.title}}</span> <mat-icon>keyboard_arrow_down</mat-icon> </button> <mat-menu #language=\"matMenu\"> <button mat-menu-item *ngFor=\"let lang of languageList\" (click)=\"onLanguageSelected(lang)\">{{lang.title}}</button> </mat-menu> </div> <div> <button *ngIf=\"defaultOptions.showProfileSettings && profileSettingList.length\" mat-button [matMenuTriggerFor]=\"profileSettings\"> <mat-icon *ngIf=\"!profileImage\">account_circle</mat-icon> <img class=\"profile-image\" *ngIf=\"profileImage\" [src]=\"profileImage\" /> <span>{{fullName}}</span> <mat-icon>keyboard_arrow_down</mat-icon> </button> <mat-menu #profileSettings=\"matMenu\" class=\"profile-menu\"> <button mat-menu-item *ngFor=\"let setting of profileSettingList\" [ngClass]=\"{'divider': setting.class === 'divider'}\" (click)=\"onProfileSettingSelected(setting)\"> <span>{{setting.title}}</span> </button> </mat-menu> </div> <img class=\"site-logo\" *ngIf=\"siteLogo\" [src]=\"siteLogo\" /> </mat-toolbar>",
                styles: [".pen-navbar.mat-toolbar { min-height: 50px; padding: 0; } .pen-navbar .mat-toolbar-row { height: 50px; } .fill-remaining-space { flex: 1 1 auto;     } .mat-menu-panel.profile-menu { width: 160px; } .mat-menu-panel .child-level-1 { padding-left: 10px; } .mat-menu-panel .child-level-2 { padding-left: 20px; } .mat-menu-panel .child-level-3 { padding-left: 30px; } .mat-menu-panel .child-level-4 { padding-left: 40px; } .mat-menu-panel .divider { height: 1px; overflow: hidden; background-color: #e5e5e5; } a[hidden] { display: none!important; } .pen-navbar a:hover:not([disabled]), .pen-navbar a:focus:not([disabled]), .mat-menu-panel a:hover:not([disabled]), .mat-menu-panel a:focus:not([disabled]) { color: currentColor; text-decoration: none; outline: none; } .mat-menu-panel a[disabled]:hover, .mat-menu-panel a[disabled]:focus { text-decoration: none; outline: none; } .pen-navbar .profile-image { width: 30px; height: 30px; border-radius: 50%; } .pen-navbar .site-logo { height: 100%; background-color: rgba(255,255,255,.95); } "],
                encapsulation: ViewEncapsulation.None
            },] },
];
/**
 * @nocollapse
 */
PenNavbarComponent.ctorParameters = function () { return []; };
PenNavbarComponent.propDecorators = {
    'color': [{ type: Input },],
    'fullName': [{ type: Input },],
    'profileImage': [{ type: Input },],
    'siteLogo': [{ type: Input },],
    'selectedLanguage': [{ type: Input },],
    'options': [{ type: Input },],
    'languageList': [{ type: Input },],
    'profileSettingList': [{ type: Input },],
    'activityOwnerList': [{ type: Input },],
    'leftLinkList': [{ type: Input },],
    'rightLinkList': [{ type: Input },],
    'clickHomeIcon': [{ type: Output },],
    'clickToggleIcon': [{ type: Output },],
    'selectLanguage': [{ type: Output },],
    'selectProfileSetting': [{ type: Output },],
};

var PenNavbarModule = (function () {
    function PenNavbarModule() {
    }
    return PenNavbarModule;
}());
PenNavbarModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, MatToolbarModule, MatIconModule, MatMenuModule, MatButtonModule],
                exports: [PenNavbarComponent, CommonModule, MatToolbarModule, MatIconModule, MatMenuModule, MatButtonModule],
                declarations: [PenNavbarComponent],
                providers: [],
            },] },
];
/**
 * @nocollapse
 */
PenNavbarModule.ctorParameters = function () { return []; };

var PenetraceFrontendFoundationModule = (function () {
    function PenetraceFrontendFoundationModule() {
    }
    /**
     * @return {?}
     */
    PenetraceFrontendFoundationModule.forRoot = function () {
        return {
            ngModule: PenetraceFrontendFoundationModule,
            providers: []
        };
    };
    return PenetraceFrontendFoundationModule;
}());
PenetraceFrontendFoundationModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, BrowserAnimationsModule],
                exports: [PenSpinnerModule, PenNavbarModule],
                declarations: [],
                providers: []
            },] },
];
/**
 * @nocollapse
 */
PenetraceFrontendFoundationModule.ctorParameters = function () { return []; };

export { PenetraceFrontendFoundationModule, PenSpinnerModule, PenSpinnerComponent, PenNavbarModule, PenNavbarComponent };
